using System;
using System.Collections.Generic;
using System.IO;
using UnityEngine;
using UnityEngine.Events;

namespace Mod
{
    public class Weapons
    {
        public static void Main()
        {
ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Rifle"), //item to derive from
        NameOverride = "Vandal", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "The fully-automatic Vandal sacrifices higher spread and recoil for a linear damage range; regardless of distance.", //new item description
        CategoryOverride = ModAPI.FindCategory("Valorant"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("textures/Weapons/Vandal.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //setting the sprite
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("textures/Weapons/Vandal.png");

            //getting the FirearmBehaviour for later manipulation
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //creating a custom cartridge for the gun
            Cartridge customCartridge = ModAPI.FindCartridge("7.62x39mm"); //load a copy of the 9mm cartridge
            customCartridge.name = "Vandal cartridge"; //set a name
            customCartridge.Damage *= 1.2f; //change the damage however you like
            customCartridge.StartSpeed *= 1.8f; //change the bullet velocity
            customCartridge.PenetrationRandomAngleMultiplier *= 0.2f; //change the accuracy when the bullet travels through an object
            customCartridge.Recoil *= 1.1f; //change the recoil
            customCartridge.ImpactForce *= 0.5f; //change how much the bullet pushes the target

            //set the cartridge to the FirearmBehaviour
            firearm.Cartridge = customCartridge;

            //set the new gun sounds. this is an array of AudioClips that is picked from at random when shot
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("textures/Weapons/Vandal.wav"),
                ModAPI.LoadSound("textures/Weapons/Vandal.wav"),
                ModAPI.LoadSound("textures/Weapons/Vandal.wav"),
            };

            // set the collision box to the new sprite shape
            // this is the easiest way to fix your collision shape, but it also the slowest.
            Instance.FixColliders();
        }
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Knife"), //item to derive from
        NameOverride = "Jett's knife", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "Highly accurate throwing knives.", //new item description
        CategoryOverride = ModAPI.FindCategory("Valorant"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("textures/thumb/JettKnife.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //get the SpriteRenderer and replace its sprite with a custom one
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("textures/weapons/JettKnife.png"); 
        }
    }
);


        }
    }
}